@@ -1,10 +1,9 @@
 package Devel::WarnGlobal;
-{
-  $Devel::WarnGlobal::VERSION = '0.07';
-}
 
 use strict;
-use vars '$VERSION';
+use warnings;
+
+our $VERSION = '0.08'; # VERSION
 
 use Carp;
 
@@ -80,7 +79,7 @@ Devel::WarnGlobal
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
